commit bd53b714d32a29bdf33009f812e295667e92b930
tree b8b6e72fcda7b40d2273498bfa16ba53e15e7917
parent 20a77776c24800d1e40a73f520cfcb32239568a9
author Nick Piggin <nickpiggin@yahoo.com.au> Sun, 01 May 2005 08:58:37 -0700
committer Linus Torvalds <torvalds@ppc970.osdl.org> Sun, 01 May 2005 08:58:37 -0700
                                                                                
    [PATCH] mm: use __GFP_NOMEMALLOC
                                                                                
    Use the new __GFP_NOMEMALLOC to simplify the previous handling of
    PF_MEMALLOC.
 
    Signed-off-by: Nick Piggin <nickpiggin@yahoo.com.au>
    Signed-off-by: Andrew Morton <akpm@osdl.org>
    Signed-off-by: Linus Torvalds <torvalds@osdl.org>

[Upstream]
--- diff/drivers/md/dm-crypt.c	2005-06-29 17:57:08.000000000 +0100
+++ source/drivers/md/dm-crypt.c	2005-06-29 17:59:08.000000000 +0100
@@ -331,25 +331,19 @@
 	struct bio *bio;
 	unsigned int nr_iovecs = (size + PAGE_SIZE - 1) >> PAGE_SHIFT;
 	int gfp_mask = GFP_NOIO | __GFP_HIGHMEM;
-	unsigned long flags = current->flags;
 	unsigned int i;
 
 	/*
-	 * Tell VM to act less aggressively and fail earlier.
-	 * This is not necessary but increases throughput.
+	 * Use __GFP_NOMEMALLOC to tell the VM to act less aggressively and
+	 * to fail earlier.  This is not necessary but increases throughput.
 	 * FIXME: Is this really intelligent?
 	 */
-	current->flags &= ~PF_MEMALLOC;
-
 	if (base_bio)
-		bio = bio_clone(base_bio, GFP_NOIO);
+		bio = bio_clone(base_bio, GFP_NOIO|__GFP_NOMEMALLOC);
 	else
-		bio = bio_alloc(GFP_NOIO, nr_iovecs);
-	if (!bio) {
-		if (flags & PF_MEMALLOC)
-			current->flags |= PF_MEMALLOC;
+		bio = bio_alloc(GFP_NOIO|__GFP_NOMEMALLOC, nr_iovecs);
+	if (!bio)
 		return NULL;
-	}
 
 	/* if the last bio was not complete, continue where that one ended */
 	bio->bi_idx = *bio_vec_idx;
@@ -386,9 +380,6 @@
 		size -= bv->bv_len;
 	}
 
-	if (flags & PF_MEMALLOC)
-		current->flags |= PF_MEMALLOC;
-
 	if (!bio->bi_size) {
 		bio_put(bio);
 		return NULL;
